/// <reference types="node" />
import * as beet from '@metaplex-foundation/beet';
import * as web3 from '@solana/web3.js';
import { ListingConfigVersion } from '../types/ListingConfigVersion';
import { Bid } from '../types/Bid';
export declare type ListingConfigArgs = {
    version: ListingConfigVersion;
    startTime: beet.bignum;
    endTime: beet.bignum;
    highestBid: Bid;
    bump: number;
    reservePrice: beet.bignum;
    minBidIncrement: beet.bignum;
    timeExtPeriod: number;
    timeExtDelta: number;
    allowHighBidCancel: boolean;
};
export declare class ListingConfig implements ListingConfigArgs {
    readonly version: ListingConfigVersion;
    readonly startTime: beet.bignum;
    readonly endTime: beet.bignum;
    readonly highestBid: Bid;
    readonly bump: number;
    readonly reservePrice: beet.bignum;
    readonly minBidIncrement: beet.bignum;
    readonly timeExtPeriod: number;
    readonly timeExtDelta: number;
    readonly allowHighBidCancel: boolean;
    private constructor();
    static fromArgs(args: ListingConfigArgs): ListingConfig;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [ListingConfig, number];
    static fromAccountAddress(connection: web3.Connection, address: web3.PublicKey): Promise<ListingConfig>;
    static deserialize(buf: Buffer, offset?: number): [ListingConfig, number];
    serialize(): [Buffer, number];
    static get byteSize(): number;
    static getMinimumBalanceForRentExemption(connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    static hasCorrectByteSize(buf: Buffer, offset?: number): boolean;
    pretty(): {
        version: string;
        startTime: beet.bignum;
        endTime: beet.bignum;
        highestBid: Bid;
        bump: number;
        reservePrice: number | {
            toNumber: () => number;
        };
        minBidIncrement: number | {
            toNumber: () => number;
        };
        timeExtPeriod: number;
        timeExtDelta: number;
        allowHighBidCancel: boolean;
    };
}
export declare const listingConfigBeet: beet.BeetStruct<ListingConfig, ListingConfigArgs & {
    accountDiscriminator: number[];
}>;
